@@ -1,14 +1,22 @@
 import sys
 import os
 import logging
+import warnings
+import colorlog
+from typing import Union, List
 from typing import Type
 from enum import Enum
 from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker, scoped_session
 from sqlalchemy.pool import NullPool, QueuePool
 from airflow.configuration import conf, AirflowConfigException, log
+from airflow.version import version as AIRFLOW_VERSION
 
 AIRFLOW_CONFIG_SECTION_NAME = "db_logger"
+AIRFLOW_VERSION_PARTS = AIRFLOW_VERSION.split(".")
+AIRFLOW_VERSION_PARTS = [int(v) for v in AIRFLOW_VERSION_PARTS]
+
+AIRFLOW_MAJOR_VERSION = AIRFLOW_VERSION_PARTS[0]
 
 
 def conf_get_no_warnings_no_errors(*args, **kwargs):
@@ -27,11 +35,20 @@ def get(
     default=None,
     otype: Type = None,
     allow_empty: bool = False,
-    collection: str = None,
+    collection: Union[str, List[str]] = None,
 ):
+    collection = collection or "db_logger"
+    collection = collection if isinstance(collection, list) else [collection]
     otype = otype or str if default is None else default.__class__
     collection = collection or AIRFLOW_CONFIG_SECTION_NAME
-    val = conf_get_no_warnings_no_errors(collection, key)
+    for col in collection:
+        val = conf_get_no_warnings_no_errors(col, key)
+        if val is not None:
+            break
+
+    assert all([isinstance(v, str) for v in collection]), AirflowConfigException(
+        "Collection must be a non empty string or a collection of non empty strings"
+    )
 
     if issubclass(otype, Enum):
         allow_empty = False
@@ -39,7 +56,9 @@ def get(
     value_is_empty = val is None or (isinstance(val, str) and len(val.strip()) == 0)
 
     if not allow_empty and value_is_empty:
-        assert default is not None, f"Airflow configuration {collection}.{key} not found, and no default value"
+        assert default is not None, AirflowConfigException(
+            f"Airflow configuration {collection}.{key} not found, and no default value"
+        )
         return default
 
     if val is None:
@@ -54,18 +73,18 @@ def get(
 
 
 # Loading airflow parameters
-LOG_LEVEL = get(collection="core", key="logging_level").upper()
-FILENAME_TEMPLATE = get(collection="core", key="LOG_FILENAME_TEMPLATE")
+LOG_LEVEL = get(collection=["logging", "core"], key="logging_level").upper()
+FILENAME_TEMPLATE = get(collection=["logging", "core"], key="LOG_FILENAME_TEMPLATE")
 AIRFLOW_EXECUTOR = get(collection="core", key="executor")
 IS_RUNNING_DEBUG_EXECUTOR = AIRFLOW_EXECUTOR == "DebugExecutor"
-IS_USING_COLORED_CONSOLE = get(collection="core", key="colored_console_log").lower() == "true"
+IS_USING_COLORED_CONSOLE = get(collection=["logging", "core"], key="colored_console_log").lower() == "true"
 
 # Loading sql parameters
 SQL_ALCHEMY_CONN = get(collection="core", key="sql_alchemy_conn", allow_empty=False)
 DAGS_FOLDER = os.path.expanduser(get(collection="core", key="dags_folder"))
-BASE_LOG_FOLDER = os.path.expanduser(get(collection="core", key="base_log_folder"))
+BASE_LOG_FOLDER = os.path.expanduser(get(collection=["logging", "core"], key="base_log_folder"))
 SQL_ALCHEMY_SCHEMA = get(collection="core", key="sql_alchemy_schema", allow_empty=True)
-COLORED_CONSOLE_LOG = get(collection="core", key="colored_console_log")
+
 TASK_LOG_FILENAME_TEMPLATE = (
     get(
         collection="core",
@@ -85,12 +104,13 @@ PROCESS_LOG_FILENAME_TEMPLATE = (
     .replace("}}}}", "}}")
 )
 
-
+DB_LOGGER_LOG_LEVEL = get(key="logging_level", default="INFO").upper()
 DB_LOGGER_SQL_ALCHEMY_SCHEMA = get("sql_alchemy_schema", SQL_ALCHEMY_SCHEMA)
 DB_LOGGER_SQL_ALCHEMY_CONNECTION = get("sql_alchemy_conn", SQL_ALCHEMY_CONN)
 DB_LOGGER_SHOW_REVERSE_ORDER = get("show_reverse", False)
 DB_LOGGER_SQL_ALCHEMY_CONNECTION_ARGS = get("sql_alchemy_conn_args", None, allow_empty=True)
 DB_LOGGER_CREATE_INDEXES = get("create_index", True)
+DB_LOGGER_WRITE_DAG_PROCESSING_TO_DB = get("write_dag_processing_to_db", False)
 
 DB_LOGGER_SQL_ALCHEMY_POOL_ENABLED = get("sql_alchemy_pool_enabled", False)
 DB_LOGGER_SQL_ALCHEMY_POOL_SIZE = get("sql_alchemy_pool_size", 5)
@@ -104,6 +124,7 @@ DB_LOGGER_GOOGLE_APP_CREDS_PATH = get("google_application_credentials", default=
 DB_LOGGER_WRITE_TO_GCS_BUCKET = get("write_to_gcs_bucket", default=None, allow_empty=True, otype=str)
 DB_LOGGER_WRITE_TO_GCS_PROJECT_ID = get("write_to_gcs_project_id", default=None, allow_empty=True, otype=str)
 DB_LOGGER_WRITE_TO_GCS_MULTI_FILE_LOG = get("write_to_gcs_multi_file_log", default=False)
+DB_LOGGER_PROCESSER_LOG_LEVEL = get("processer_log_level", default="WARN", allow_empty=True, otype=str)
 # True or path
 DB_LOGGER_WRITE_TO_FILES = get("write_to_files", default=False)
 # True or path
@@ -205,19 +226,42 @@ def init_logger(reset=False):
     """
     from airflow_db_logger.data import LoggerModelBase
 
-    logging.info(f"Using {DB_LOGGER_SQL_ALCHEMY_CONNECTION}")
+    log.info(f"AirflowDBLogger is using: {DB_LOGGER_SQL_ALCHEMY_CONNECTION}")
     if reset:
         # NOTE: There is no promp for logs, when you reset, everything will reset always.
-        logging.info("Resetting db_logger tables...")
+        log.info("Resetting db_logger tables...")
         LoggerModelBase.metadata.drop_all(DB_LOGGER_ENGINE)
     else:
-        logging.info("Initialzing db_logger tables...")
+        log.info("Initialzing db_logger tables...")
     LoggerModelBase.metadata.create_all(DB_LOGGER_ENGINE)
 
-    logging.info("db_logger tables initialized.")
+    log.info("AirflowDBLogger tables initialized.")
 
 
 def check_cli_for_init_db():
     """Returns true if the cli command is for initializing the database."""
+    # Old system
     if "initdb" in sys.argv or "upgradedb" in sys.argv or "resetdb" in sys.argv:
         init_logger("resetdb" in sys.argv)
+
+    # New system
+    if "db" in sys.argv and ("reset" in sys.argv or "init" in sys.argv or "upgrade" in sys.argv):
+        init_logger("reset" in sys.argv)
+
+
+airflow_db_logger_log = logging.getLogger(__file__)
+airflow_db_logger_log.setLevel(DB_LOGGER_LOG_LEVEL)
+airflow_db_logger_log.propagate = False
+airflow_db_logger_log.handlers.clear()
+stderr_handler = logging.StreamHandler(stream=sys.__stderr__)
+if not IS_USING_COLORED_CONSOLE:
+    stderr_handler.setFormatter(logging.Formatter(fmt="[%(asctime)s][airflow_db_logger][%(levelname)s] %(message)s"))
+else:
+    stderr_handler.setFormatter(
+        colorlog.ColoredFormatter(
+            fmt="%(blue)s[%(asctime)s]%(purple)s[airflow_db_logger]%(log_color)s[%(levelname)s]%(reset)s %(message)s"
+        )
+    )
+
+airflow_db_logger_log.addHandler(stderr_handler)
+airflow_db_logger_log.info("Initialized.")
