@@ -7,6 +7,7 @@ from zthreading.events import EventHandler, Event
 from airflow.utils.helpers import parse_template_string
 from airflow.models import TaskInstance
 from sqlalchemy import asc, desc
+import traceback
 
 from airflow_db_logger.exceptions import DBLoggerException
 from airflow_db_logger.utils import get_calling_frame_objects_by_type
@@ -16,21 +17,17 @@ from airflow_db_logger.config import (
     DBLoggerSession,
     DAGS_FOLDER,
     IS_RUNNING_DEBUG_EXECUTOR,
+    IS_USING_COLORED_CONSOLE,
     DB_LOGGER_SHOW_REVERSE_ORDER,
     TASK_LOG_FILENAME_TEMPLATE,
     PROCESS_LOG_FILENAME_TEMPLATE,
     DB_LOGGER_WRITE_TO_FILES,
     DB_LOGGER_WRITE_TO_GCS_BUCKET,
     DB_LOGGER_WRITE_TO_SHELL,
+    AIRFLOW_MAJOR_VERSION,
+    airflow_db_logger_log,
 )
 
-stderr_logger = logging.getLogger(__file__)
-stderr_logger.propagate = False
-stderr_logger.handlers.clear()
-stderr_handler = logging.StreamHandler(stream=sys.__stderr__)
-stderr_handler.setFormatter(logging.Formatter(fmt="[%(asctime)s][DBLOGGER] [%(levelname)s] - %(message)s"))
-stderr_logger.addHandler(stderr_handler)
-
 
 class ExecutionLogTaskContextInfo:
     def __init__(self, task_instance: TaskInstance):
@@ -47,6 +44,20 @@ class DBLoggingEventHandler(EventHandler):
     close_event_name: str = "close"
 
 
+class StreamHandler(logging.StreamHandler):
+    def __init__(self, stream: str = None, level: str = None) -> None:
+        stream = stream or "stdout"
+        self._use_stderr = "stderr" in stream
+        logging.Handler.__init__(self, level=level or LOG_LEVEL)
+
+    @property
+    def stream(self):
+        if self._use_stderr:
+            return sys.__stderr__
+
+        return sys.__stdout__
+
+
 class DBLogStreamWriter(DBLoggingEventHandler):
     _stream_writers: List["DBLogStreamWriter"] = None
 
@@ -223,7 +234,7 @@ class DBTaskLogHandler(DBLogHandler):
             self._logfile_subpath = os.path.join(self.subfolder_path, self._render_logfile_subpath())
             super().set_context()
         except Exception as err:
-            stderr_logger.error(err)
+            airflow_db_logger_log.error(err)
 
     def emit(self, record: logging.LogRecord):
         """Emits a log record.
@@ -251,7 +262,11 @@ class DBTaskLogHandler(DBLogHandler):
                 self.db_session.add(db_record)
                 self.db_session.commit()
             except Exception:
-                stderr_logger.error(traceback.format_exc())
+                try:
+                    self.db_session.rollback()
+                except:
+                    pass
+                airflow_db_logger_log.error(traceback.format_exc())
 
         super().emit(record)
 
@@ -296,6 +311,10 @@ class DBTaskLogHandler(DBLogHandler):
 
             logs_by_try_number: Dict[int, List[TaskExecutionLogRecord]] = dict()
 
+            airflow_db_logger_log.info(
+                f"Reading logs: {task_instance.dag_id}/{task_instance.task_id} {try_numbers} {{{task_instance.execution_date}}}"
+            )
+
             log_records_query = (
                 db_session.query(TaskExecutionLogRecord)
                 .filter(TaskExecutionLogRecord.dag_id == task_instance.dag_id)
@@ -318,7 +337,6 @@ class DBTaskLogHandler(DBLogHandler):
 
             # pull the records
             log_records: List[TaskExecutionLogRecord] = [r for r in log_records]
-            # log_records.sort(key=lambda r: r.timestamp.timestamp())
 
             for log_record in log_records:
                 try_number = int(log_record.try_number)
@@ -327,19 +345,35 @@ class DBTaskLogHandler(DBLogHandler):
                 logs_by_try_number[try_number].append(str(log_record.text))
 
             for try_number in logs_by_try_number.keys():
-                logs_by_try_number[try_number] = "\n".join(logs_by_try_number[try_number])
+                logs_by_try_number[try_number] = str("\n".join(logs_by_try_number[try_number]))
 
             try_numbers.sort()
             logs = []
             metadata_array = []
             for try_number in try_numbers:
-                logs.append(logs_by_try_number[try_number])
+                # logs.appen
+                log = logs_by_try_number.get(try_number, "[No logs found]")
+                if AIRFLOW_MAJOR_VERSION > 1:
+                    log = [(task_instance.hostname, log)]
+                logs.append(log)
                 metadata_array.append({"end_of_log": True})
 
+            # airflow_db_logger_log.info(traceback.format_stack().j)
+            # traceback.print_stack()
+            airflow_db_logger_log.info(f"Read {len(logs)} logs")
+
             return logs, metadata_array
 
-        except Exception as err:
-            stderr_logger.error(err)
+        except Exception:
+            if db_session:
+                try:
+                    db_session.rollback()
+                except Exception:
+                    pass
+            airflow_db_logger_log.error(traceback.format_exc())
+            return [f"An error occurred while connecting to the database:\n" + f"{traceback.format_exc()}"], [
+                {"end_of_log": True}
+            ]
         finally:
             if db_session:
                 db_session.close()
@@ -382,13 +416,6 @@ class DBProcessLogHandler(DBLogHandler):
         """
         filename = os.path.relpath(filename, self.dag_dir)
         return f"{filename}.log"
-        # ctx = dict()
-        # ctx["filename"] = filename
-
-        # if self.filename_jinja_template:
-        #     return self.filename_jinja_template.render(**ctx)
-
-        # return self.filename_template.format(filename=ctx["filename"])
 
     def set_context(self, filepath=None):
         """Initialize the dag log configuration.
@@ -407,9 +434,8 @@ class DBProcessLogHandler(DBLogHandler):
             )
             self._db_session = DBLoggerSession()
         except Exception:
-            logging.error("Failed to initialize process logger contexts")
-            traceback.print_exc()
-            # logging.error(err)
+            airflow_db_logger_log.error("Failed to initialize process logger contexts")
+            airflow_db_logger_log.error(traceback.format_exc())
 
     def get_logfile_subpath(self):
         assert self._log_filepath, DBLoggerException(
@@ -432,7 +458,11 @@ class DBProcessLogHandler(DBLogHandler):
             self.db_session.add(db_record)
             self.db_session.commit()
         except Exception:
-            stderr_logger.error(f"Error while attempting to log ({self._log_filepath}): {db_record_message}")
-            stderr_logger.error(traceback.format_exc())
+            try:
+                self.db_session.rollback()
+            except:
+                pass
+            airflow_db_logger_log.error(f"Error while attempting to log ({self._log_filepath}): {db_record_message}")
+            airflow_db_logger_log.error(traceback.format_exc())
 
         super().emit(record)
